pub fn inspect_tensor(
tensor: &Tensor,
options: TensorInspectionOptions,
) -> Result<TensorInspection, DataError>Expand description
Inspects a tensor without cloning or materializing its backing storage.
Errors
Propagates a layout bounds error if a tensor invariant has been violated.